@@ -58,6 +58,7 @@ AwsCreds = namedtuple('AwsCreds', [
     'access_key_id', 'secret_access_key', 'pre_auth_headers',
 ])
 
+s3_client = None
 
 class ExpiringDict:
 
@@ -112,6 +113,9 @@ class CortxJupyterSecretAccessKeyAuthentication(CortxJupyterAuthentication):
             secret_access_key=self.aws_secret_access_key,
             pre_auth_headers=self.pre_auth_headers,
         )
+    s3_client = boto3.client('s3', aws_access_key_id=self.aws_access_key_id,
+                         aws_secret_access_key=self.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+
 
 
 class CortxJupyter(ContentsManager):
@@ -720,7 +724,7 @@ def _list_keys(context, key_prefix, delimiter):
 
     @gen.coroutine
     def _list_first_page():
-
+        print(type(context.s3_bucket))
         response = yield _list_objects(context.s3_bucket, key_prefix, delimiter, max_keys)
 
 
@@ -803,8 +807,6 @@ SAVERS = {
 
 # 'endpoint_url': AwsCreds.endpoint_url,
 
-s3_client = boto3.client('s3', aws_access_key_id=AwsCreds.access_key_id,
-                         aws_secret_access_key=AwsCreds.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
 
 
 def _head_object(bucket, key):
@@ -846,4 +848,4 @@ def _list_objects(bucket, prefix, delimiter, max_keys, token=''):
         Delimiter=delimiter,
         MaxKeys=max_keys,
         Prefix=prefix,
-        ContinuationToken=token)
+        ContinuationToken='')
